summaryrefslogtreecommitdiffstats
path: root/src/likeback.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 14:58:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 14:58:21 -0600
commit7864df7a5e0a69bb3e525ec3e47256bdcbf2832b (patch)
tree3aa53b371fc2482fb6bea9f8eca16b9524c1b332 /src/likeback.h
parent3cedb6a5f7a9c3e0c04303289e025ce6fe91e164 (diff)
downloadbasket-7864df7a5e0a69bb3e525ec3e47256bdcbf2832b.tar.gz
basket-7864df7a5e0a69bb3e525ec3e47256bdcbf2832b.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'src/likeback.h')
-rw-r--r--src/likeback.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/likeback.h b/src/likeback.h
index c3d1f25..7a2c90f 100644
--- a/src/likeback.h
+++ b/src/likeback.h
@@ -25,8 +25,8 @@
class TDEConfig;
class TDEAboutData;
-class KAction;
-class KActionCollection;
+class TDEAction;
+class TDEActionCollection;
class LikeBackPrivate;
class LikeBackBar;
@@ -48,7 +48,7 @@ class LikeBackDialog;
*
* The LikeBack system has 5 components:
* @li In the application: The comment dialog, where the user write a comment, select a type of comment, etc.
* @li In the application: The KAction to plug in the Help menu. This action displays the comment dialog.
* @li In the application: The button-bar, that floats bellow titlebar of every windows of the application, and let the user to quickly show the comment dialog.
* The button-bar can be hidden.
* @li On the server: A PHP script that collects every comments that users send. The LikeBack object should be configured to contact that server.
@@ -64,7 +64,7 @@ class LikeBackDialog;
* // Comment the following line once you are sure all your windows have a name:
* likeBack->setWindowNamesListing(LikeBack::WarnUnnamedWindows);
*
- * // This line should be called early in your KMainWindow constructor because it references actionCollection().
+ * // This line should be called early in your TDEMainWindow constructor because it references actionCollection().
* // It should be called before createGUI() for the action to be plugged in the Help menu:
* likeBack->sendACommentAction(actionCollection());
* @endcode
@@ -129,7 +129,7 @@ class LikeBack : public TQObject
/**
* Destructor.
* Also hide the button-bar, if it was shown.
* Be careful, the KAction is deleted. Do not use it afterward, and take care to unplug it before destroying this LikeBack instance.
*/
~LikeBack();
@@ -210,7 +210,7 @@ class LikeBack : public TQObject
TQ_UINT16 hostPort();
/**
* Get the KAction letting user to show the comment dialog.
* You should plug it in your Help menu, just bellow the "Report a Bug" action, or replace it.
* Adding the action below "Report a Bug" or replacing "Report a Bug" depends on your application and if you have a Bugzilla account.
* If you do not have a Bugzilla account, LikeBack is a good way for your small application to get bug reports: remove "Report a Bug".
@@ -220,7 +220,7 @@ class LikeBack : public TQObject
* <Action name="likeback_send_a_comment" />
* @endcode
*/
- KAction* sendACommentAction(KActionCollection *parent = 0);
+ TDEAction* sendACommentAction(TDEActionCollection *parent = 0);
/**
* @Returns The path of the currently active window. Each windows are separated with "~~".
@@ -281,7 +281,7 @@ class LikeBack : public TQObject
* @param windowPath The window path to send with the comment. If empty (the default), the current window path is took.
* Separate window names with "~~". For instance "MainWindow~~NewFile~~FileOpen".
* If you popup the dialog after an error occurred, you can put the error name in that field (if the window path has no sense in that context).
* When the dialog is popuped up from the sendACommentAction() KAction, this value is "HelpMenu", because there is no way to know if the user
* is commenting a thing he found/thinked about in a sub-dialog.
* @param context Not used for the moment. Will allow more fine-grained application status report.
*/
@@ -303,7 +303,7 @@ class LikeBack : public TQObject
private slots:
/**
* Slot triggered by the "Help -> Send a Comment to Developers" KAction.
* It popups the comment dialog, and set the window path to "HelpMenuAction",
* because current window path has no meaning in that case.
*/
@@ -48,7 +48,7 @@ class LikeBackDialog;
* The LikeBack system has 5 components:
* @li In the application: The comment dialog, where the user write a comment, select a type of comment, etc.
- * @li In the application: The KAction to plug in the Help menu. This action displays the comment dialog.
+ * @li In the application: The TDEAction to plug in the Help menu. This action displays the comment dialog.
* @li In the application: The button-bar, that floats bellow titlebar of every windows of the application, and let the user to quickly show the comment dialog.
* The button-bar can be hidden.
@@ -129,7 +129,7 @@ class LikeBack : public TQObject
* Destructor.
* Also hide the button-bar, if it was shown.
- * Be careful, the KAction is deleted. Do not use it afterward, and take care to unplug it before destroying this LikeBack instance.
+ * Be careful, the TDEAction is deleted. Do not use it afterward, and take care to unplug it before destroying this LikeBack instance.
*/
~LikeBack();
@@ -210,7 +210,7 @@ class LikeBack : public TQObject
TQ_UINT16 hostPort();
/**
- * Get the KAction letting user to show the comment dialog.
+ * Get the TDEAction letting user to show the comment dialog.
* You should plug it in your Help menu, just bellow the "Report a Bug" action, or replace it.
* Adding the action below "Report a Bug" or replacing "Report a Bug" depends on your application and if you have a Bugzilla account.
@@ -281,7 +281,7 @@ class LikeBack : public TQObject
* Separate window names with "~~". For instance "MainWindow~~NewFile~~FileOpen".
* If you popup the dialog after an error occurred, you can put the error name in that field (if the window path has no sense in that context).
- * When the dialog is popuped up from the sendACommentAction() KAction, this value is "HelpMenu", because there is no way to know if the user
+ * When the dialog is popuped up from the sendACommentAction() TDEAction, this value is "HelpMenu", because there is no way to know if the user
* is commenting a thing he found/thinked about in a sub-dialog.
* @param context Not used for the moment. Will allow more fine-grained application status report.
@@ -303,7 +303,7 @@ class LikeBack : public TQObject
private slots:
/**
- * Slot triggered by the "Help -> Send a Comment to Developers" KAction.
+ * Slot triggered by the "Help -> Send a Comment to Developers" TDEAction.
* It popups the comment dialog, and set the window path to "HelpMenuAction",
* because current window path has no meaning in that case.